
# Slot: has confidence level


connects an association to a qualitative term denoting the level of confidence

URI: [biolink:has_confidence_level](https://w3id.org/biolink/vocab/has_confidence_level)


## Domain and Range

[Association](Association.md) &#8594;  <sub>0..1</sub> [ConfidenceLevel](ConfidenceLevel.md)

## Parents

 *  is_a: [association slot](association_slot.md)

## Children


## Used by

